/*--------- Timeline ----------*/
.admin-timeline #content h1 {
	color: #555;
	font-size: 20px;
	background: #FFF;
	padding: 5px;
	text-align: center;
	}

.admin-timeline #content #content-main h1 {
	color: #acacac;
	font-size: 18px;
	background: #FFF;
	padding: 5px;
	text-align: center;
	}

.admin-timeline .actionlist {
	width: 700px;
	float: left;
	}
.admin-timeline ul li {
    list-style: none;
}
.admin-timeline .actionlist li {
	position: relative;
	}
.admin-timeline .actionlist .even,
.admin-timeline .actionlist .odd{
	width: 350px;
	padding: 30px 0 50px 0;
	}
.admin-timeline .actionlist .even{
	border-right: 3px solid #3c3c3c;
	}
.admin-timeline .actionlist .odd {
	margin-left: 350px;
	border-left: 3px solid #3c3c3c;
	}
.admin-timeline .module h2,
.admin-timeline .actionlist .time-entry{
	background: #1db5ea;
	color: #FFF;
	font-size: 12px;
	height: 25px;
	text-align: center;
	line-height: 25px;
	display: block;
	position:absolute;
	top: 15px;
	border-bottom: 1px solid #FFF;
	padding: 0 15px;
	}
.admin-timeline .actionlist .even .time-entry  {
	right: 0;
	}
.admin-timeline .actionlist .inner-block {
	border: 1px solid #bdbdbd;
    background-color: #eeeeee;
	padding: 25px 15px 10px 15px;
	}
.admin-timeline .actionlist .inner-block h3 {
	font-size: 12px;
	}
.admin-timeline .actionlist .inner-block h3 span{
	font-weight: normal;
	}
.admin-timeline .actionlist .even .inner-block{
	border-right: none;
	}
.admin-timeline .actionlist .odd .inner-block{
	border-left: none;
	}
.admin-timeline .actionlist .inner-block a span.change {
	font-size: smaller;
    clear: left;
    display: block;
    font-style: italic;
	}

/*--------- End timeline ---------*/

/*--------- Filter form ---------*/
.admin-timeline-filter-form {
    position: fixed;
    top: 58px;
    right: 0;
    width: 200px;
}

.admin-timeline-filter-form label {
    background-color: #EEEEEE;
    padding: 3px 0 3px 5px;
    border: 1px solid #BDBDBD;
    border-right: medium none;
    border-left: medium none;
    border-bottom: medium none;
    width: 100%;
    display: block;
    font-weight: bold;
    font-size: 11px;
    color: #555;
}

.admin-timeline-filter-form button {
    padding: 0 16px;
    background: none no-repeat scroll right top #999999;
    border: 2px solid #999999;
    color: #FFFFFF;
    font-weight: normal;
    border-radius: 12px;
    line-height: 13px;
}
.admin-timeline-filter-form button:hover {
    background: none no-repeat scroll right top #5b80b2;
    border: 2px solid #5b80b2;
    cursor: pointer;
}

.admin-timeline-filter-form ul {
    display: block;
    margin: 5px 0 10px 0;
    padding: 0;
}
    .admin-timeline-filter-form ul li {
        padding: 2px;
        margin: 0;
    }
        .admin-timeline-filter-form ul li label {
            background: none;
            padding: auto;
            border: none;
            display: inline;
            font-weight: normal;
            color: #000;
        }

/*--------- End filter form ---------*/